@@ -8,12 +8,18 @@ __author__  = "Elena Antusheva, 2008"
 __license__ = "GPL"
 __version__ = "$Revision: 12897 $"
 
-class AnyTitileSubscriberBase(object) :
 
+from interfaces import IAnyTitle
+from zope.interface import implements
+
+class AnyTitleSubscriberBase(object) :
+
+    implements(IAnyTitle)
     order = 0
 
     def __init__(self,context) :
         self.context = context
 
     def __cmp__(self,x) :
-        return cmp(self.order,x.order)
\ No newline at end of file
+        return cmp(self.order,x.order)
+        
\ No newline at end of file
