@@ -1,13 +1,14 @@
 ### -*- coding: utf-8 -*- #############################################
 #######################################################################
-"""Product class for the Zope 3 based product package
+"""Contained2PathAdapter class for the Zope 3 based ng.adapter.path package
 
 $Id: product.py 12897 2007-11-10 15:32:08Z cray $
 """
-__author__  = "Yegor Shershnev"
+__author__  = "Yegor Shershnev, 2007"
 __license__ = "GPL"
 __version__ = "$Revision: 12897 $"
 
+
 from zope.interface import implements
 from zope.app.container.interfaces import IContained
 from interfaces import IPath
@@ -15,6 +16,7 @@ from zope.component import adapts
 from ng.adapter.title.interfaces import ITitle
 from pathadapterbase import PathAdapterBase
 
+
 class Contained2PathAdapter(PathAdapterBase) :
 
     implements(IPath)
@@ -38,4 +40,4 @@ class Contained2PathAdapter(PathAdapterBase) :
         next = IPath(IContained(self.context).__parent__)
         return next._tailpath(
             path + ("/".join((next.name,path[-1])),)
-        )        
\ No newline at end of file
+        )
